/*
 * Epson Inkjet Printer Driver (ESC/P-R) for Linux
 * Copyright (C) Seiko Epson Corporation 2002-2015.
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA.
 */

#ifndef LIB_PRT_X_H
#define LIB_PRT_X_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#define NAME_MAX 41

#include "pipsDef.h"
#include "../escprlib/include/epson-escpr-pvt.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*** Index of printing quality                                                      */
/*** -------------------------------------------------------------------------------*/
typedef EPS_INT32 (* EPS_FPSPOOLFUNC)(void* hParam, 
        const EPS_UINT8* pBuf, EPS_UINT32 cbBuf);

typedef struct tagEPS_OPT{
    EPS_FPSPOOLFUNC    fpspoolfunc;    /* pointer to spool function */
}EPS_OPT;

typedef struct rtp_filter_option {
	char model[NAME_MAX + 1];
	char model_low[NAME_MAX + 1];
	char ink[NAME_MAX + 1];
	char media[NAME_MAX + 1];
	char quality[NAME_MAX + 1];
	char duplex[NAME_MAX + 1];
	char inputslot[NAME_MAX + 1];
	char borderless[NAME_MAX + 1];
	char duty[NAME_MAX + 1];
	char dryingtime[NAME_MAX + 1];
	char cyanvalue[NAME_MAX + 1];
	char magentavalue[NAME_MAX + 1];
	char yellowvalue[NAME_MAX + 1];
	char brightness[NAME_MAX + 1];
	char contrast[NAME_MAX + 1];
	char saturation[NAME_MAX + 1];
#ifdef GCOMSW_PRIVATE				// RHV2
	char compression[NAME_MAX + 1];	//
	char line[NAME_MAX + 1];		//
	char colorspace[NAME_MAX + 1];	//
#endif
	double custom_width_min;
	double custom_width_max;
	double custom_height_min;
	double custom_height_max;									//
} filter_option_t;


typedef void *handle_t;
typedef int (*INIT_FUNC) (const EPS_OPT *, const EPS_PRINT_JOB*);
typedef int (*PINIT_FUNC) (void);
typedef int (*OUT_FUNC) (const EPS_BANDBMP *, EPS_RECT *);
typedef int (*PEND_FUNC) (const EPS_UINT8);
typedef int (*END_FUNC) (void);  
typedef int (*FILTER_PMPEPLY_FUNC) (EPS_UINT8 *);

//Custom Size Range (mm)
#define ROLL_WIDTH_89_MM   89
#define ROLL_WIDTH_102_MM  101.6
#define ROLL_WIDTH_127_MM  127
#define ROLL_WIDTH_152_MM  152.4
#define ROLL_WIDTH_203_MM  203.2
#define ROLL_WIDTH_210_MM  210

#define ROLL_HEIGHT_MIN_MM  50
#define ROLL_HEIGHT_MAX_MM  1000

#define SHEET_WIDTH_MIN_MM  89
#define SHEET_WIDTH_MAX_MM  210
#define SHEET_HEIGHT_MIN_MM  148
#define SHEET_HEIGHT_MAX_MM  1000
#define SHEET_HEIGHT_MAX2_MM  297

//#define SHEET_WIDTH_DUPLEX_MIN_MM  89
//#define SHEET_WIDTH_DUPLEX_MAX_MM  210
//#define SHEET_HEIGHT_DUPLEX_MIN_MM  148
//#define SHEET_HEIGHT_DUPLEX_MAX_MM  297

#define SHEET_WIDTH_BORDERLESS_100_MM  100
#define SHEET_WIDTH_BORDERLESS_102_MM  101.6
#define SHEET_WIDTH_BORDERLESS_127_MM  127
#define SHEET_WIDTH_BORDERLESS_152_MM  152.4
#define SHEET_WIDTH_BORDERLESS_203_MM  203.2
#define SHEET_WIDTH_BORDERLESS_210_MM  210


//Custom Size Range (inch)
#define ROLL_WIDTH_3_5_IN   3.5
#define ROLL_WIDTH_4_IN     4
#define ROLL_WIDTH_5_IN     5
#define ROLL_WIDTH_6_IN     6
#define ROLL_WIDTH_8_IN     8
#define ROLL_WIDTH_8_27_IN  8.27

#define ROLL_HEIGHT_MIN_IN  1.97
#define ROLL_HEIGHT_MAX_IN  39.37

#define SHEET_WIDTH_MIN_IN  3.5
#define SHEET_WIDTH_MAX_IN  8.270001
#define SHEET_HEIGHT_MIN_IN  5.82999
#define SHEET_HEIGHT_MAX_IN  39.37
#define SHEET_HEIGHT_MAX2_IN  11.69

//#define SHEET_WIDTH_DUPLEX_MIN_IN  3.5
//#define SHEET_WIDTH_DUPLEX_MAX_IN  8.27
//#define SHEET_HEIGHT_DUPLEX_MIN_IN 5.83
//#define SHEET_HEIGHT_DUPLEX_MAX_IN 39.37

#define SHEET_WIDTH_BORDERLESS_3_94_IN  3.94
#define SHEET_WIDTH_BORDERLESS_4_IN  4
#define SHEET_WIDTH_BORDERLESS_5_IN  5
#define SHEET_WIDTH_BORDERLESS_6_IN  6
#define SHEET_WIDTH_BORDERLESS_8_IN  8
#define SHEET_WIDTH_BORDERLESS_8_3_IN  8.27



#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* LIB_PRT_X_H */
